LlvmSymbolName

Trait LlvmSymbolName 

pub trait LlvmSymbolName: Op + SymbolOpInterface {
    // Provided methods
    fn llvm_symbol_name(&self, ctx: &Context) -> Option<String> { ... }
    fn set_llvm_symbol_name(&self, ctx: &Context, name: String) { ... }
}
Since LLVM symbols can have characters that are illegal in pliron, this interface provides a way to get the original LLVM symbol name.

Provided Methods

fn llvm_symbol_name(&self, ctx: &Context) -> Option<String>

Get the original LLVM symbol name, if it’s different from the pliron symbol name.

fn set_llvm_symbol_name(&self, ctx: &Context, name: String)

Set the original LLVM symbol name.