ScalarOrVectorResImpls

Trait ScalarOrVectorResImpls 

pub trait ScalarOrVectorResImpls<I: ?Sized + TypeInterfaceMarker + 'static, const N: usize>: Op {
    // Provided methods
    fn scalar_or_vector_elem_ty(&self, ctx: &Context) -> TypeInterfaceHandle<I> { ... }
    fn vector_shape(&self, ctx: &Context) -> Option<(u32, VectorTypeKind)> { ... }
}
A result whose type either impls I or is VectorType<T: I>.

Provided Methods

fn scalar_or_vector_elem_ty(&self, ctx: &Context) -> TypeInterfaceHandle<I>

Get the type of result N, or its element type if its VectorType.

fn vector_shape(&self, ctx: &Context) -> Option<(u32, VectorTypeKind)>

Get the vector shape of result N, or None if it is not a VectorType.